@@ -13,7 +13,7 @@ from netsuite.swagger_client.rest_client import RestClient
 from netsuite.settings import APISettings
 from netsuite.storages import BaseStorage, JSONStorage
 
-NETSUITE_CERT_ID = "o3rCX1bKSBEm8PqpjwwQuHZ2cvJnIC2uo0KsQxbahMg"
+# NETSUITE_CERT_ID = "o3rCX1bKSBEm8PqpjwwQuHZ2cvJnIC2uo0KsQxbahMg"
 # BASE_DIR = str(pathlib.Path(__file__).parent.resolve())
 # NETSUITE_KEY_FILENAME = "netsuite-key.pem"
 # NETSUITE_KEY_PATH = (os.path.join(BASE_DIR, "keys", f"{NETSUITE_KEY_FILENAME}"))
@@ -40,14 +40,15 @@ class Netsuite:
             raise Exception("Missing Client Id")
         if not self.api_settings.NETSUITE_APP_NAME:
             raise Exception("Missing Netsuite App Name")
-        if not self.api_settings.NETSUITE_CERTIFICATE_PATH:
+        if not self.api_settings.CERT_FILE:
             raise Exception("Missing Netsuite Certificate path.")
-        if not self.api_settings.NETSUITE_CERTIFICATE_ID:
+        if not self.api_settings.CERT_ID:
             raise Exception("Missing Netsuite Certificate ID.")
 
         self.app_name = self.api_settings.APP_NAME
         self.netsuite_app_name = self.api_settings.NETSUITE_APP_NAME
-        self.netsuite_key_path = self.api_settings.NETSUITE_CERTIFICATE_PATH
+        self.netsuite_key_path = self.api_settings.NETSUITE_KEY_FILE
+        self.netsuite_cert_id = self.api_settings.CERT_ID
 
         self.storage = self.api_settings.STORAGE_CLASS()
         if isinstance(self.api_settings.STORAGE_CLASS(), JSONStorage):
@@ -93,7 +94,7 @@ class Netsuite:
         headers = {
             "typ": "JWT",
             "alg": "RS256",
-            "kid": f"{NETSUITE_CERT_ID}"
+            "kid": f"{self.netsuite_cert_id}"
         }
 
         jwt_token = jwt.encode(payload=payload, key=private_key, algorithm='RS256', headers=headers)
